@@ -538,7 +538,8 @@ struct SECOidDataStr {
 #define NSS_USE_ALG_IN_SSL_KX 0x00000004         /* used in SSL key exchange */
 #define NSS_USE_ALG_IN_SSL 0x00000008            /* used in SSL record protocol */
 #define NSS_USE_POLICY_IN_SSL 0x00000010         /* enable policy in SSL protocol */
-#define NSS_USE_ALG_IN_ANY_SIGNATURE 0x00000020  /* used in S/MIME */
+#define NSS_USE_ALG_IN_ANY_SIGNATURE 0x00000020  /* used in any signature */
+#define NSS_USE_ALG_IN_PKCS12 0x00000040         /* used in pkcs12 */
 #define NSS_USE_DEFAULT_NOT_VALID 0x80000000     /* clear to make the default flag valid */
 #define NSS_USE_DEFAULT_SSL_ENABLE 0x40000000    /* default cipher suite setting 1=enable */
 
